<?php


/**
 * Class - Queue
 */
class wps_ic_queue extends wps_ic {

  public $options;
  public $queue_table;


  public function __construct() {
    if (is_admin()) {
      global $wpdb;

      $this->queue_table = $wpdb->prefix . 'ic_queue';
      $this->options     = new wps_ic_options();
    }
  }


  public function remove_queue_type($type) {
    global $wpdb;

    $type = sanitize_text_field($type);

    $queue = $wpdb->prepare("SELECT attachment_ID FROM " . $wpdb->prefix . "ic_queue WHERE type=%s", $type);
    $queue = $wpdb->get_results($queue);

    if ($queue) {

      foreach ($queue as $row) {
        delete_post_meta($row->attachment_ID, 'wps_ic_data');
        delete_post_meta($row->attachment_ID, 'wps_ic_data');
        delete_post_meta($row->attachment_ID, 'wps_ic_times');

        $query = $wpdb->prepare("UPDATE " . $wpdb->prefix . "ic_queue SET status='-1' WHERE attachment_ID='" . $row->attachment_ID . "'");
        $wpdb->query($query);
      }

      return true;
    }

    return false;
  }


  public function clear_queue($type, $meta = false) {
    global $wpdb, $wps_ic;

    $type = sanitize_text_field($type);

    if ($meta) {
      $wps_ic->ajax->wps_ic_fixing(false);
    }

    $delete = $wpdb->prepare("DELETE FROM " . $wpdb->prefix . "ic_queue WHERE type=%s", $type);
    $delete = $wpdb->query($delete);

    if ($delete) {
      return true;
    }

    return false;
  }


  public function add_queue($attachment_id, $type, $old_meta = '', $new_meta = '') {
    global $wpdb;

    $attachment_id = (int)$attachment_id;
    $type          = sanitize_text_field($type);

    $insert = $wpdb->prepare("INSERT INTO " . $wpdb->prefix . "ic_queue (attachment_ID, type, created) VALUES (%s, %s, %s) ON DUPLICATE KEY UPDATE created=%s",
                             $attachment_id,
                             $type,
                             current_time('mysql'),
                             current_time('mysql'));

    $insert = $wpdb->query($insert);

    if ($insert) {
      return true;
    } else {
      return false;
    }
  }


  public function update_compress_queue($attachment_id, $status = '1', $new_meta = '') {
    global $wpdb;

    $status        = (int)$status;
    $attachment_id = (int)$attachment_id;

    $update = $wpdb->prepare("UPDATE " . $wpdb->prefix . "ic_queue SET status=%s, new_meta=%s WHERE attachment_ID=%s", $status, $new_meta, $attachment_id);

    $update = $wpdb->query($update);

    if ($update) {
      return true;
    }

    return false;
  }


  public function remove_restore_queue($attachment_id) {
    $this->remove_queue($attachment_id);
  }


  public function remove_queue($attachment_id) {
    global $wpdb;

    $attachment_id = (int)$attachment_id;

    $delete = $wpdb->prepare("DELETE FROM " . $wpdb->prefix . "ic_queue WHERE attachment_ID=%s", $attachment_id);
    $delete = $wpdb->query($delete);

    if ($delete) {
      return true;
    }

    return false;
  }


  public function remove_compress_queue($attachment_id) {
    $this->remove_queue($attachment_id);
  }


  public function remove_compress_preview_queue($attachment_id) {
    $this->remove_queue($attachment_id);
  }


  public function get_restore_queue($attachment_id = '') {
    return $this->get_queue('restore', $attachment_id);
  }


  public function get_queue($type, $attachment_id = '') {
    global $wpdb;

    $type          = sanitize_text_field($type);
    $attachment_id = (int)$attachment_id;

    $output          = array();
    $args            = array();
    $where_attach_id = '';

    $args[] = $type;

    // Query WHERE clause if param not empty
    if ( ! empty($attachment_id) && $attachment_id != 0) {
      $where_attach_id = ' AND attachment_ID=%s';
      $args[]          = $attachment_id;
    }

    // Prepare query
    $fetch = $wpdb->prepare("SELECT attachment_ID, type, status FROM " . $wpdb->prefix . "ic_queue WHERE type=%s" . $where_attach_id, $args);

    $fetch = $wpdb->get_results($fetch);

    if ($fetch) {
      foreach ($fetch as $row) {
        $output[ $row->attachment_ID ] = array('type' => $row->type, 'status' => $row->status);
      }
    }

    if (!empty($output)) {
      return $output;
    } else {
      return false;
    }
  }


  public function get_restore_bulk_queue($attachment_id = '') {
    return $this->get_queue('restore_bulk', $attachment_id);
  }


  public function get_compress_bulk_queue($attachment_id = '') {
    return $this->get_queue('compress_bulk', $attachment_id);
  }


  public function get_compress_queue($attachment_id = '') {
    return $this->get_queue('compress', $attachment_id);
  }


  public function get_compress_preview_queue($attachment_id = '') {
    return $this->get_queue('compress_preview', $attachment_id);
  }


}